nsim.analysesN package
======================

Submodules
----------

nsim.analysesN.epochs module
----------------------------

.. automodule:: nsim.analysesN.epochs
    :members:
    :undoc-members:
    :show-inheritance:

nsim.analysesN.misc module
--------------------------

.. automodule:: nsim.analysesN.misc
    :members:
    :undoc-members:
    :show-inheritance:

nsim.analysesN.phase module
---------------------------

.. automodule:: nsim.analysesN.phase
    :members:
    :undoc-members:
    :show-inheritance:

nsim.analysesN.plots module
---------------------------

.. automodule:: nsim.analysesN.plots
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: nsim.analysesN
    :members:
    :undoc-members:
    :show-inheritance:
